@@ -83,57 +83,57 @@ setMethod(
   }
 )
 
-setGeneric("get_demand_controls", function(object) {
-  standardGeneric("get_demand_controls")
+setGeneric("demand_controls", function(object) {
+  standardGeneric("demand_controls")
 })
 
-setMethod("get_demand_controls", signature(object = "simulated_model"), function(object) {
+setMethod("demand_controls", signature(object = "simulated_model"), function(object) {
   as.matrix(object@simulation_tbl[, grep("Xd", names(object@simulation_tbl))])
 })
 
-setGeneric("get_supply_controls", function(object) {
-  standardGeneric("get_supply_controls")
+setGeneric("supply_controls", function(object) {
+  standardGeneric("supply_controls")
 })
 
-setMethod("get_supply_controls", signature(object = "simulated_model"), function(object) {
+setMethod("supply_controls", signature(object = "simulated_model"), function(object) {
   as.matrix(object@simulation_tbl[, grep("Xs", names(object@simulation_tbl))])
 })
 
-setGeneric("get_common_controls", function(object) {
-  standardGeneric("get_common_controls")
+setGeneric("common_controls", function(object) {
+  standardGeneric("common_controls")
 })
 
-setMethod("get_common_controls", signature(object = "simulated_model"), function(object) {
+setMethod("common_controls", signature(object = "simulated_model"), function(object) {
   as.matrix(object@simulation_tbl[, grep("X\\d", names(object@simulation_tbl))])
 })
 
-setGeneric("get_simulated_demanded_quantities", function(object, prices) {
-  standardGeneric("get_simulated_demanded_quantities")
+setGeneric("simulated_demanded_quantities", function(object, prices) {
+  standardGeneric("simulated_demanded_quantities")
 })
 
 setMethod(
-  "get_simulated_demanded_quantities", signature(object = "simulated_model"),
+  "simulated_demanded_quantities", signature(object = "simulated_model"),
   function(object, prices) {
     as.vector(
       prices * object@alpha_d +
-        object@beta_d0 + get_demand_controls(object) %*% object@beta_d +
-        get_common_controls(object) %*% object@eta_d +
+        object@beta_d0 + demand_controls(object) %*% object@beta_d +
+        common_controls(object) %*% object@eta_d +
         object@simulation_tbl$u_d
     )
   }
 )
 
-setGeneric("get_simulated_supplied_quantities", function(object, prices) {
-  standardGeneric("get_simulated_supplied_quantities")
+setGeneric("simulated_supplied_quantities", function(object, prices) {
+  standardGeneric("simulated_supplied_quantities")
 })
 
 setMethod(
-  "get_simulated_supplied_quantities", signature(object = "simulated_model"),
+  "simulated_supplied_quantities", signature(object = "simulated_model"),
   function(object, prices) {
     as.vector(
       prices * object@alpha_s +
-        object@beta_s0 + get_supply_controls(object) %*% object@beta_s +
-        get_common_controls(object) %*% object@eta_s +
+        object@beta_s0 + supply_controls(object) %*% object@beta_s +
+        common_controls(object) %*% object@eta_s +
         object@simulation_tbl$u_s
     )
   }
@@ -177,9 +177,9 @@ setGeneric("simulate_shocks", function(object) {
 })
 
 setMethod("simulate_shocks", signature(object = "simulated_model"), function(object) {
-  cov_ds <- object@sigma_d * object@sigma_s * object@rho_ds
+  sigma_ds <- object@sigma_d * object@sigma_s * object@rho_ds
   object@mu <- c(0, 0)
-  object@sigma <- matrix(c(object@sigma_d**2, cov_ds, cov_ds, object@sigma_s**2), 2, 2)
+  object@sigma <- matrix(c(object@sigma_d**2, sigma_ds, sigma_ds, object@sigma_s**2), 2, 2)
 
   disturbances <- MASS::mvrnorm(n = nrow(object@simulation_tbl), object@mu, object@sigma)
   colnames(disturbances) <- c("u_d", "u_s")
@@ -237,9 +237,9 @@ setMethod(
   function(
            object, demanded_quantities, supplied_quantities, prices, starting_prices) {
     scale <- (object@alpha_d - object@alpha_s)
-    x_d <- get_demand_controls(object)
-    x_s <- get_supply_controls(object)
-    x <- get_common_controls(object)
+    x_d <- demand_controls(object)
+    x_s <- supply_controls(object)
+    x <- common_controls(object)
 
     prices <- as.vector(
       (x %*% (object@eta_s - object@eta_d) +
@@ -248,8 +248,8 @@ setMethod(
         object@simulation_tbl$u_s - object@simulation_tbl$u_d
       ) / scale
     )
-    demanded_quantities <- get_simulated_demanded_quantities(object, prices)
-    supplied_quantities <- get_simulated_supplied_quantities(object, prices)
+    demanded_quantities <- simulated_demanded_quantities(object, prices)
+    supplied_quantities <- simulated_supplied_quantities(object, prices)
 
     callNextMethod(object, demanded_quantities, supplied_quantities, prices, starting_prices)
   }
@@ -266,8 +266,8 @@ setMethod(
   function(
            object, demanded_quantities, supplied_quantities, prices, starting_prices) {
     prices <- object@price_generator(nrow(object@simulation_tbl))
-    demanded_quantities <- get_simulated_demanded_quantities(object, prices)
-    supplied_quantities <- get_simulated_supplied_quantities(object, prices)
+    demanded_quantities <- simulated_demanded_quantities(object, prices)
+    supplied_quantities <- simulated_supplied_quantities(object, prices)
 
     callNextMethod(object, demanded_quantities, supplied_quantities, prices, starting_prices)
   }
@@ -284,8 +284,8 @@ setMethod(
   function(
            object, demanded_quantities, supplied_quantities, prices, starting_prices) {
     starting_prices <- object@price_generator(object@nobs)
-    r_d <- get_simulated_demanded_quantities(object, 0)
-    r_s <- get_simulated_supplied_quantities(object, 0)
+    r_d <- simulated_demanded_quantities(object, 0)
+    r_s <- simulated_supplied_quantities(object, 0)
 
     demand_columns <- grep("Xd", names(object@simulation_tbl))
     supply_columns <- grep("Xs", names(object@simulation_tbl))
@@ -320,13 +320,13 @@ setMethod(
             MASS::mvrnorm(n = 1, object@mu, object@sigma)
           )
           r_d[i_offset + t] <- (
-            object@beta_d0 + get_demand_controls(object)[i_offset + t, ] %*% object@beta_d +
-              get_common_controls(object)[i_offset + t, ] %*% object@eta_d +
+            object@beta_d0 + demand_controls(object)[i_offset + t, ] %*% object@beta_d +
+              common_controls(object)[i_offset + t, ] %*% object@eta_d +
               object@simulation_tbl$u_d[i_offset + t]
           )
           r_s[i_offset + t] <- (
-            object@beta_s0 + get_supply_controls(object)[i_offset + t, ] %*% object@beta_s +
-              get_common_controls(object)[i_offset + t, ] %*% object@eta_s +
+            object@beta_s0 + supply_controls(object)[i_offset + t, ] %*% object@beta_s +
+              common_controls(object)[i_offset + t, ] %*% object@eta_s +
               object@simulation_tbl$u_s[i_offset + t]
           )
         }
@@ -354,13 +354,13 @@ setMethod(
   "simulate_quantities_and_prices", signature(object = "simulated_deterministic_adjustment_model"),
   function(
            object, demanded_quantities, supplied_quantities, prices, starting_prices) {
-    r_d <- get_simulated_demanded_quantities(object, 0)
-    r_s <- get_simulated_supplied_quantities(object, 0)
+    r_d <- simulated_demanded_quantities(object, 0)
+    r_s <- simulated_supplied_quantities(object, 0)
     dr <- r_d - r_s
 
     if (class(object) == "simulated_stochastic_adjustment_model") {
       dr <- dr + object@gamma * (
-        object@beta_p0 + get_price_controls(object) %*% object@beta_p + object@simulation_tbl$u_p
+        object@beta_p0 + price_controls(object) %*% object@beta_p + object@simulation_tbl$u_p
       )
     }
 
@@ -377,8 +377,8 @@ setMethod(
       }
     }
 
-    demanded_quantities <- get_simulated_demanded_quantities(object, prices)
-    supplied_quantities <- get_simulated_supplied_quantities(object, prices)
+    demanded_quantities <- simulated_demanded_quantities(object, prices)
+    supplied_quantities <- simulated_supplied_quantities(object, prices)
 
     callNextMethod(object, demanded_quantities, supplied_quantities, prices, starting_prices)
   }
@@ -457,12 +457,12 @@ setMethod(
   }
 )
 
-setGeneric("get_price_controls", function(object) {
-  standardGeneric("get_price_controls")
+setGeneric("price_controls", function(object) {
+  standardGeneric("price_controls")
 })
 
 setMethod(
-  "get_price_controls", signature(object = "simulated_stochastic_adjustment_model"),
+  "price_controls", signature(object = "simulated_stochastic_adjustment_model"),
   function(object) {
     as.matrix(object@simulation_tbl[, grep("Xp", names(object@simulation_tbl))])
   }
@@ -481,15 +481,15 @@ setMethod(
 setMethod(
   "simulate_shocks", signature(object = "simulated_stochastic_adjustment_model"),
   function(object) {
-    cov_ds <- object@sigma_d * object@sigma_s * object@rho_ds
-    cov_dp <- object@sigma_d * object@sigma_p * object@rho_dp
-    cov_sp <- object@sigma_s * object@sigma_p * object@rho_sp
+    sigma_ds <- object@sigma_d * object@sigma_s * object@rho_ds
+    sigma_dp <- object@sigma_d * object@sigma_p * object@rho_dp
+    sigma_sp <- object@sigma_s * object@sigma_p * object@rho_sp
 
     object@mu <- c(0, 0, 0)
     object@sigma <- matrix(
       c(
-        object@sigma_d**2, cov_ds, cov_dp, cov_ds,
-        object@sigma_s**2, cov_sp, cov_dp, cov_sp,
+        object@sigma_d**2, sigma_ds, sigma_dp, sigma_ds,
+        object@sigma_s**2, sigma_sp, sigma_dp, sigma_sp,
         object@sigma_p**2
       ),
       3, 3
@@ -555,91 +555,91 @@ setGeneric(
 
 #' @rdname simulate_model_data
 setMethod(
-    "simulate_model_data", signature(),
-    function(
-             model_string, nobs, tobs,
-             alpha_d, beta_d0, beta_d, eta_d,
-             alpha_s, beta_s0, beta_s, eta_s,
-             gamma, beta_p0, beta_p,
-             sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
-             seed,
-             price_generator, control_generator) {
-        if (model_string == "equilibrium_model") {
-            sim_mdl <- new(
-                "simulated_equilibrium_model",
-                nobs, tobs,
-                alpha_d, beta_d0, beta_d, eta_d,
-                alpha_s, beta_s0, beta_s, eta_s,
-                sigma_d, sigma_s, rho_ds,
-                seed,
-                price_generator, control_generator
-            )
-            stopifnot(abs(sim_mdl@simulation_tbl$XD) < sqrt(.Machine$double.eps))
-        }
-        else if (model_string == "diseq_basic") {
-            sim_mdl <- new(
-                "simulated_basic_model",
-                nobs, tobs,
-                alpha_d, beta_d0, beta_d, eta_d,
-                alpha_s, beta_s0, beta_s, eta_s,
-                sigma_d, sigma_s, rho_ds,
-                seed,
-                price_generator, control_generator
-            )
-            xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
-            stopifnot(xd_share < 0.9 && xd_share > 0.1)
-        }
-        else if (model_string == "diseq_directional") {
-            sim_mdl <- new(
-                "simulated_directional_model",
-                nobs, tobs,
-                alpha_d, beta_d0, beta_d, eta_d,
-                alpha_s, beta_s0, beta_s, eta_s,
-                sigma_d, sigma_s, rho_ds,
-                seed,
-                price_generator, control_generator
-            )
-            stopifnot(sim_mdl@simulation_tbl$DP * sim_mdl@simulation_tbl$XD >= 0)
-            xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
-            stopifnot(xd_share < 0.9 && xd_share > 0.1)
-        }
-        else if (model_string == "diseq_deterministic_adjustment") {
-            sim_mdl <- new(
-                "simulated_deterministic_adjustment_model",
-                nobs, tobs,
-                alpha_d, beta_d0, beta_d, eta_d,
-                alpha_s, beta_s0, beta_s, eta_s,
-                gamma,
-                sigma_d, sigma_s, rho_ds,
-                seed,
-                price_generator, control_generator
-            )
-            stopifnot(abs(
-                sim_mdl@gamma * sim_mdl@simulation_tbl$DP - sim_mdl@simulation_tbl$XD
-            ) < sqrt(.Machine$double.eps))
-            xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
-            stopifnot(xd_share < 0.9 && xd_share > 0.1)
-        }
-        else if (model_string == "diseq_stochastic_adjustment") {
-            sim_mdl <- new(
-                "simulated_stochastic_adjustment_model",
-                nobs, tobs,
-                alpha_d, beta_d0, beta_d, eta_d,
-                alpha_s, beta_s0, beta_s, eta_s,
-                gamma, beta_p0, beta_p,
-                sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
-                seed,
-                price_generator, control_generator
-            )
-            xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
-            stopifnot(xd_share < 0.9 && xd_share > 0.1)
-        }
-        else {
-            stop("Unhandled model type.")
-        }
-
-        sim_mdl@simulation_tbl
+  "simulate_model_data", signature(),
+  function(
+           model_string, nobs, tobs,
+           alpha_d, beta_d0, beta_d, eta_d,
+           alpha_s, beta_s0, beta_s, eta_s,
+           gamma, beta_p0, beta_p,
+           sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
+           seed,
+           price_generator, control_generator) {
+    if (model_string == "equilibrium_model") {
+      sim_mdl <- new(
+        "simulated_equilibrium_model",
+        nobs, tobs,
+        alpha_d, beta_d0, beta_d, eta_d,
+        alpha_s, beta_s0, beta_s, eta_s,
+        sigma_d, sigma_s, rho_ds,
+        seed,
+        price_generator, control_generator
+      )
+      stopifnot(abs(sim_mdl@simulation_tbl$XD) < sqrt(.Machine$double.eps))
     }
+    else if (model_string == "diseq_basic") {
+      sim_mdl <- new(
+        "simulated_basic_model",
+        nobs, tobs,
+        alpha_d, beta_d0, beta_d, eta_d,
+        alpha_s, beta_s0, beta_s, eta_s,
+        sigma_d, sigma_s, rho_ds,
+        seed,
+        price_generator, control_generator
+      )
+      xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
+      stopifnot(xd_share < 0.9 && xd_share > 0.1)
+    }
+    else if (model_string == "diseq_directional") {
+      sim_mdl <- new(
+        "simulated_directional_model",
+        nobs, tobs,
+        alpha_d, beta_d0, beta_d, eta_d,
+        alpha_s, beta_s0, beta_s, eta_s,
+        sigma_d, sigma_s, rho_ds,
+        seed,
+        price_generator, control_generator
+      )
+      stopifnot(sim_mdl@simulation_tbl$DP * sim_mdl@simulation_tbl$XD >= 0)
+      xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
+      stopifnot(xd_share < 0.9 && xd_share > 0.1)
+    }
+    else if (model_string == "diseq_deterministic_adjustment") {
+      sim_mdl <- new(
+        "simulated_deterministic_adjustment_model",
+        nobs, tobs,
+        alpha_d, beta_d0, beta_d, eta_d,
+        alpha_s, beta_s0, beta_s, eta_s,
+        gamma,
+        sigma_d, sigma_s, rho_ds,
+        seed,
+        price_generator, control_generator
+      )
+      stopifnot(abs(
+        sim_mdl@gamma * sim_mdl@simulation_tbl$DP - sim_mdl@simulation_tbl$XD
+      ) < sqrt(.Machine$double.eps))
+      xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
+      stopifnot(xd_share < 0.9 && xd_share > 0.1)
+    }
+    else if (model_string == "diseq_stochastic_adjustment") {
+      sim_mdl <- new(
+        "simulated_stochastic_adjustment_model",
+        nobs, tobs,
+        alpha_d, beta_d0, beta_d, eta_d,
+        alpha_s, beta_s0, beta_s, eta_s,
+        gamma, beta_p0, beta_p,
+        sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
+        seed,
+        price_generator, control_generator
+      )
+      xd_share <- sum(sim_mdl@simulation_tbl$XD > 0) / nrow(sim_mdl@simulation_tbl)
+      stopifnot(xd_share < 0.9 && xd_share > 0.1)
+    }
+    else {
+      stop("Unhandled model type.")
+    }
+
+    sim_mdl@simulation_tbl
+  }
 )
 
 
@@ -658,91 +658,91 @@ setGeneric(
 
 
 setMethod(
-    "simulate_model", signature(),
-    function(
-             model_string, nobs, tobs,
-             alpha_d, beta_d0, beta_d, eta_d,
-             alpha_s, beta_s0, beta_s, eta_s,
-             gamma, beta_p0, beta_p,
-             sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
-             seed, verbose) {
-        sdt <- simulate_model_data(
-            model_string, nobs, tobs,
-            alpha_d, beta_d0, beta_d, eta_d,
-            alpha_s, beta_s0, beta_s, eta_s,
-            gamma, beta_p0, beta_p,
-            sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
-            seed
-        )
+  "simulate_model", signature(),
+  function(
+           model_string, nobs, tobs,
+           alpha_d, beta_d0, beta_d, eta_d,
+           alpha_s, beta_s0, beta_s, eta_s,
+           gamma, beta_p0, beta_p,
+           sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
+           seed, verbose) {
+    sdt <- simulate_model_data(
+      model_string, nobs, tobs,
+      alpha_d, beta_d0, beta_d, eta_d,
+      alpha_s, beta_s0, beta_s, eta_s,
+      gamma, beta_p0, beta_p,
+      sigma_d, sigma_s, sigma_p, rho_ds, rho_dp, rho_sp,
+      seed
+    )
 
-        key_columns <- c("id", "date")
-        time_column <- c("date")
-        quantity_column <- "Q"
-        price_column <- "P"
-        demand_specification <- paste(
-            price_column, paste("Xd", seq_along(beta_d), sep = "", collapse = " + "),
-            paste("X", seq_along(eta_d), sep = "", collapse = " + "),
-            sep = " + "
-        )
-        supply_specification <- paste(
-            paste("Xs", seq_along(beta_s), sep = "", collapse = " + "),
-            paste("X", seq_along(eta_s), sep = "", collapse = " + "),
-            sep = " + "
-        )
-        if (model_string != "diseq_directional") {
-            supply_specification <- paste0(price_column, " + ", supply_specification)
-        }
-        price_specification <- paste("Xp", seq_along(beta_p), sep = "", collapse = " + ")
-
-        use_correlated_shocks <- TRUE
-
-
-        if (model_string %in% c("equilibrium_model", "diseq_basic")) {
-            model <- new(
-                model_string,
-                key_columns,
-                quantity_column, price_column, demand_specification, supply_specification,
-                sdt,
-                use_correlated_shocks = use_correlated_shocks, verbose = verbose
-            )
-        }
-        else if (model_string %in% c("diseq_directional", "diseq_deterministic_adjustment")) {
-            model <- new(
-                model_string,
-                key_columns, time_column,
-                quantity_column, price_column, demand_specification, supply_specification,
-                sdt,
-                use_correlated_shocks = use_correlated_shocks, verbose = verbose
-            )
-        }
-        else if (model_string %in% c("diseq_stochastic_adjustment")) {
-            model <- new(
-                model_string,
-                key_columns, time_column,
-                quantity_column, price_column,
-                demand_specification, supply_specification, price_specification,
-                sdt,
-                use_correlated_shocks = use_correlated_shocks, verbose = verbose
-            )
-        }
-        else {
-            stop("Unhandled model type.")
-        }
-
-        model
+    key_columns <- c("id", "date")
+    time_column <- c("date")
+    quantity_column <- "Q"
+    price_column <- "P"
+    demand_specification <- paste(
+      price_column, paste("Xd", seq_along(beta_d), sep = "", collapse = " + "),
+      paste("X", seq_along(eta_d), sep = "", collapse = " + "),
+      sep = " + "
+    )
+    supply_specification <- paste(
+      paste("Xs", seq_along(beta_s), sep = "", collapse = " + "),
+      paste("X", seq_along(eta_s), sep = "", collapse = " + "),
+      sep = " + "
+    )
+    if (model_string != "diseq_directional") {
+      supply_specification <- paste0(price_column, " + ", supply_specification)
     }
+    price_specification <- paste("Xp", seq_along(beta_p), sep = "", collapse = " + ")
+
+    correlated_shocks <- TRUE
+
+
+    if (model_string %in% c("equilibrium_model", "diseq_basic")) {
+      model <- new(
+        model_string,
+        key_columns,
+        quantity_column, price_column, demand_specification, supply_specification,
+        sdt,
+        correlated_shocks = correlated_shocks, verbose = verbose
+      )
+    }
+    else if (model_string %in% c("diseq_directional", "diseq_deterministic_adjustment")) {
+      model <- new(
+        model_string,
+        key_columns, time_column,
+        quantity_column, price_column, demand_specification, supply_specification,
+        sdt,
+        correlated_shocks = correlated_shocks, verbose = verbose
+      )
+    }
+    else if (model_string %in% c("diseq_stochastic_adjustment")) {
+      model <- new(
+        model_string,
+        key_columns, time_column,
+        quantity_column, price_column,
+        demand_specification, supply_specification, price_specification,
+        sdt,
+        correlated_shocks = correlated_shocks, verbose = verbose
+      )
+    }
+    else {
+      stop("Unhandled model type.")
+    }
+
+    model
+  }
 )
 
-simulate_equilibrium_model_model <- function(parameters, seed, verbose) {
-    simulate_model(
-        "equilibrium_model", parameters$nobs, parameters$tobs,
-        parameters$alpha_d, parameters$beta_d0, parameters$beta_d, parameters$eta_d,
-        parameters$alpha_s, parameters$beta_s0, parameters$beta_s, parameters$eta_s,
-        NA, NA, c(NA),
-        sigma_d = parameters$sigma_d, sigma_s = parameters$sigma_s, sigma_p = NA,
-        rho_ds = parameters$rho_ds, rho_dp = NA, rho_sp = NA,
-        seed = seed, verbose = verbose
-    )
+simulate_equilibrium_model <- function(parameters, seed, verbose) {
+  simulate_model(
+    "equilibrium_model", parameters$nobs, parameters$tobs,
+    parameters$alpha_d, parameters$beta_d0, parameters$beta_d, parameters$eta_d,
+    parameters$alpha_s, parameters$beta_s0, parameters$beta_s, parameters$eta_s,
+    NA, NA, c(NA),
+    sigma_d = parameters$sigma_d, sigma_s = parameters$sigma_s, sigma_p = NA,
+    rho_ds = parameters$rho_ds, rho_dp = NA, rho_sp = NA,
+    seed = seed, verbose = verbose
+  )
 }
 
 simulate_basic_model <- function(parameters, seed, verbose) {
