@@ -30,13 +30,3 @@ setMethod(
     .Object
   }
 )
-
-setMethod("calculate_lh", signature(object = "system_directional"), function(object) {
-  (object@demand@Psi * object@demand@separation_subset) / object@demand@sigma +
-    (object@supply@Psi * object@supply@separation_subset) / object@supply@sigma
-})
-
-setMethod("set_parameters", signature(object = "system_directional"), function(object, parameters) {
-  object <- callNextMethod(object, parameters)
-  object
-})
